@@ -20,17 +20,18 @@
 
 This module defines the :class:`FCIL1cNCFileHandler` file handler, to
 be used for reading Meteosat Third Generation (MTG) Flexible Combined
-Imager (FCI) Level-1c data.  FCI will fly
+Imager (FCI) Level-1c data.  FCI flies
 on the MTG Imager (MTG-I) series of satellites, with the first satellite (MTG-I1)
-scheduled to be launched on the 13th of December 2022.
+launched on the 13th of December 2022.
 For more information about FCI, see `EUMETSAT`_.
 
 For simulated test data to be used with this reader, see `test data releases`_.
 For the Product User Guide (PUG) of the FCI L1c data, see `PUG`_.
 
 .. note::
+    This reader supports data from both IDPF-I and IQT-I processing facilities.
     This reader currently supports Full Disk High Spectral Resolution Imagery
-    (FDHSI), High Spatial Resolution Fast Imagery (HRFI) data in full-disc ("FD") scanning mode.
+    (FDHSI), High Spatial Resolution Fast Imagery (HRFI) data in full-disc ("FD") or in RSS ("Q4") scanning mode.
     In addition it also supports the L1C format for the African dissemination ("AF"), where each file
     contains the masked full-dic of a single channel see `AF PUG`_.
     If the user provides a list of both FDHSI and HRFI files from the same repeat cycle to the Satpy ``Scene``,
@@ -109,7 +110,7 @@ All auxiliary data can be obtained by prepending the channel name such as
 
 .. _AF PUG: https://www-cdn.eumetsat.int/files/2022-07/MTG%20EUMETCast%20Africa%20Product%20User%20Guide%20%5BAfricaPUG%5D_v2E.pdf
 .. _PUG: https://www-cdn.eumetsat.int/files/2020-07/pdf_mtg_fci_l1_pug.pdf
-.. _EUMETSAT: https://www.eumetsat.int/mtg-flexible-combined-imager  # noqa: E501
+.. _EUMETSAT: https://user.eumetsat.int/resources/user-guides/mtg-fci-level-1c-data-guide  # noqa: E501
 .. _test data releases: https://www.eumetsat.int/mtg-test-data
 """
 
@@ -123,6 +124,7 @@ import dask.array as da
 import numpy as np
 import xarray as xr
 from netCDF4 import default_fillvals
+from pyorbital.astronomy import sun_earth_distance_correction
 from pyresample import geometry
 
 from satpy.readers._geos_area import get_geos_area_naming
@@ -216,25 +218,40 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
         logger.debug("Start: {}".format(self.start_time))
         logger.debug("End: {}".format(self.end_time))
 
+        if self.filename_info["coverage"] == "Q4":
+            # change the chunk number so that padding gets activated correctly for Q4, which corresponds to the upper
+            # quarter of the disc
+            self.filename_info["count_in_repeat_cycle"] += 28
+
+        if self.filename_info["coverage"] == "AF":
+            # change number of chunk from 0 to 1 so that the padding is not activated (chunk 1 is present and only 1
+            # chunk is expected), as the African dissemination products come in one file per full disk.
+            self.filename_info["count_in_repeat_cycle"] = 1
+
+        if self.filename_info["facility_or_tool"] == "IQTI":
+            self.is_iqt = True
+        else:
+            self.is_iqt = False
+
         self._cache = {}
 
     @property
     def rc_period_min(self):
-        """Get nominal repeat cycle duration.
-
-        As RSS is not yet implemented an error will be raised if RSS are tried to be read.
-        """
-        if self.filename_info["coverage"] not in ["FD","AF"]:
-            raise NotImplementedError(f"coverage for {self.filename_info['coverage']} not supported by this reader")
+        """Get nominal repeat cycle duration."""
+        if "Q4" in self.filename_info["coverage"]:
             return 2.5
-        return 10
+        elif self.filename_info["coverage"] in ["FD", "AF"]:
+            return 10
+        else:
+            raise NotImplementedError(f"coverage for {self.filename_info['coverage']}"
+                                      " not supported by this reader")
 
     @property
     def nominal_start_time(self):
         """Get nominal start time."""
         rc_date = self.observation_start_time.replace(hour=0, minute=0, second=0, microsecond=0)
         return rc_date + dt.timedelta(
-            minutes=(self.filename_info["repeat_cycle_in_day"]-1)*self.rc_period_min)
+            minutes=(self.filename_info["repeat_cycle_in_day"] - 1) * self.rc_period_min)
 
     @property
     def nominal_end_time(self):
@@ -286,21 +303,21 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
         vis_06_measured_path = self.get_channel_measured_group_path("vis_06")
         ir_105_measured_path = self.get_channel_measured_group_path("ir_105")
         segment_position_info = {
-             HIGH_RES_GRID_INFO[file_type]["grid_type"]: {
-                 "start_position_row": self.get_and_cache_npxr(vis_06_measured_path + "/start_position_row").item(),
-                 "end_position_row": self.get_and_cache_npxr(vis_06_measured_path + "/end_position_row").item(),
-                 "segment_height": self.get_and_cache_npxr(vis_06_measured_path + "/end_position_row").item() -
-                 self.get_and_cache_npxr(vis_06_measured_path + "/start_position_row").item() + 1,
-                 "grid_width": HIGH_RES_GRID_INFO[file_type]["grid_width"]
-             },
-             LOW_RES_GRID_INFO[file_type]["grid_type"]: {
-                 "start_position_row": self.get_and_cache_npxr(ir_105_measured_path + "/start_position_row").item(),
-                 "end_position_row": self.get_and_cache_npxr(ir_105_measured_path + "/end_position_row").item(),
-                 "segment_height": self.get_and_cache_npxr(ir_105_measured_path + "/end_position_row").item() -
-                 self.get_and_cache_npxr(ir_105_measured_path + "/start_position_row").item() + 1,
-                 "grid_width": LOW_RES_GRID_INFO[file_type]["grid_width"]
-             }
-         }
+            HIGH_RES_GRID_INFO[file_type]["grid_type"]: {
+                "start_position_row": self.get_and_cache_npxr(vis_06_measured_path + "/start_position_row").item(),
+                "end_position_row": self.get_and_cache_npxr(vis_06_measured_path + "/end_position_row").item(),
+                "segment_height": self.get_and_cache_npxr(vis_06_measured_path + "/end_position_row").item() -
+                                  self.get_and_cache_npxr(vis_06_measured_path + "/start_position_row").item() + 1,
+                "grid_width": HIGH_RES_GRID_INFO[file_type]["grid_width"]
+            },
+            LOW_RES_GRID_INFO[file_type]["grid_type"]: {
+                "start_position_row": self.get_and_cache_npxr(ir_105_measured_path + "/start_position_row").item(),
+                "end_position_row": self.get_and_cache_npxr(ir_105_measured_path + "/end_position_row").item(),
+                "segment_height": self.get_and_cache_npxr(ir_105_measured_path + "/end_position_row").item() -
+                                  self.get_and_cache_npxr(ir_105_measured_path + "/start_position_row").item() + 1,
+                "grid_width": LOW_RES_GRID_INFO[file_type]["grid_width"]
+            }
+        }
         return segment_position_info
 
     def get_dataset(self, key, info=None):
@@ -378,11 +395,12 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
             self["attr/platform"], self["attr/platform"])
 
         # remove unpacking parameters for calibrated data
-        if key["calibration"] in ["brightness_temperature", "reflectance"]:
+        if key["calibration"] in ["brightness_temperature", "reflectance", "radiance"]:
             res.attrs.pop("add_offset")
             res.attrs.pop("warm_add_offset")
             res.attrs.pop("scale_factor")
             res.attrs.pop("warm_scale_factor")
+            res.attrs.pop("valid_range")
 
         # remove attributes from original file which don't apply anymore
         res.attrs.pop("long_name")
@@ -392,19 +410,46 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
             "nominal_end_time": self.nominal_end_time,
             "observation_start_time": self.observation_start_time,
             "observation_end_time": self.observation_end_time,
-            }
+        }
         res.attrs.update(self.orbital_param)
 
         return res
 
-    @cached_property
-    def orbital_param(self):
-        """Compute the orbital parameters for the current segment."""
+    def get_iqt_parameters_lon_lat_alt(self):
+        """Compute the orbital parameters for IQT data.
+
+        Compute satellite_actual_longitude, satellite_actual_latitude, satellite_actual_altitude.
+        """
+        actual_subsat_lon = float(self.get_and_cache_npxr("data/mtg_geos_projection/attr/"
+                                                          "longitude_of_projection_origin"))
+        actual_subsat_lat = 0.0
+        actual_sat_alt = float(self.get_and_cache_npxr("data/mtg_geos_projection/attr/perspective_point_height"))
+        logger.info("For IQT data, the following parameter is hardcoded:"
+                    f" satellite_actual_latitude = {actual_subsat_lat}. "
+                    "The following parameters are taken from the projection dictionary: "
+                    f"satellite_actual_longitude = {actual_subsat_lon}, "
+                    f"satellite_actual_altitude = {actual_sat_alt}")
+        return actual_subsat_lon, actual_subsat_lat, actual_sat_alt
+
+    def get_parameters_lon_lat_alt(self):
+        """Compute the orbital parameters.
+
+        Compute satellite_actual_longitude, satellite_actual_latitude, satellite_actual_altitude.
+        """
         actual_subsat_lon = float(np.nanmean(self._get_aux_data_lut_vector("subsatellite_longitude")))
         actual_subsat_lat = float(np.nanmean(self._get_aux_data_lut_vector("subsatellite_latitude")))
         actual_sat_alt = float(np.nanmean(self._get_aux_data_lut_vector("platform_altitude")))
-        # The "try" is a temporary part of the code as long as the AF data are not modified
-        try :
+        return actual_subsat_lon, actual_subsat_lat, actual_sat_alt
+
+    @cached_property
+    def orbital_param(self):
+        """Compute the orbital parameters for the current segment."""
+        if self.is_iqt:
+            actual_subsat_lon, actual_subsat_lat, actual_sat_alt = self.get_iqt_parameters_lon_lat_alt()
+        else:
+            actual_subsat_lon, actual_subsat_lat, actual_sat_alt = self.get_parameters_lon_lat_alt()
+        # The "try" is a temporary part of the code as long as the AF data are not fixed
+        try:
             nominal_and_proj_subsat_lon = float(
                 self.get_and_cache_npxr("data/mtg_geos_projection/attr/longitude_of_projection_origin"))
         except ValueError:
@@ -466,7 +511,6 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
 
         # get lut values from 1-d vector variable
         lut = self._get_aux_data_lut_vector(_get_aux_data_name_from_dsname(dsname))
-
         # assign lut values based on index map indices
         aux = index_map.data.map_blocks(self._getitem, lut.data, dtype=lut.data.dtype)
         aux = xr.DataArray(aux, dims=index_map.dims, attrs=index_map.attrs, coords=index_map.coords)
@@ -497,16 +541,6 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
         for coord in "xy":
             coord_radian = self.get_and_cache_npxr(measured + "/{:s}".format(coord))
 
-            # TODO remove this check when old versions of IDPF test data (<v4) are deprecated.
-            if coord == "x" and coord_radian.attrs["scale_factor"] > 0:
-                coord_radian.attrs["scale_factor"] *= -1
-
-            # TODO remove this check when old versions of IDPF test data (<v5) are deprecated.
-            if type(coord_radian.attrs["scale_factor"]) is np.float32:
-                coord_radian.attrs["scale_factor"] = coord_radian.attrs["scale_factor"].astype("float64")
-            if type(coord_radian.attrs["add_offset"]) is np.float32:
-                coord_radian.attrs["add_offset"] = coord_radian.attrs["add_offset"].astype("float64")
-
             coord_radian_num = coord_radian[:] * coord_radian.attrs["scale_factor"] + coord_radian.attrs["add_offset"]
 
             # FCI defines pixels by centroids (see PUG), while pyresample
@@ -640,7 +674,7 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
 
         measured = self.get_channel_measured_group_path(key["name"])
         data.attrs.update({"radiance_unit_conversion_coefficient":
-                          self.get_and_cache_npxr(measured + "/radiance_unit_conversion_coefficient")})
+                               self.get_and_cache_npxr(measured + "/radiance_unit_conversion_coefficient")})
         return data
 
     def calibrate_rad_to_bt(self, radiance, key):
@@ -686,20 +720,23 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
                 "channel effective solar irradiance set to fill value, "
                 "cannot produce reflectance for {:s}.".format(measured))
             return radiance * np.float32(np.nan)
-
-        sun_earth_distance = np.mean(
-            self.get_and_cache_npxr("state/celestial/earth_sun_distance")) / 149597870.7  # [AU]
-
-        # TODO remove this check when old versions of IDPF test data (<v5) are deprecated.
-        if sun_earth_distance < 0.9 or sun_earth_distance > 1.1:
-            logger.info("The variable state/celestial/earth_sun_distance contains unexpected values"
-                        "(mean value is {} AU). Defaulting to 1 AU for reflectance calculation."
-                        "".format(sun_earth_distance))
-            sun_earth_distance = 1
-
+        sun_earth_distance = self._compute_sun_earth_distance
         res = 100 * radiance * np.float32(np.pi) * np.float32(sun_earth_distance) ** np.float32(2) / cesi
         return res
 
+    @cached_property
+    def _compute_sun_earth_distance(self) -> float:
+        """Compute the sun_earth_distance."""
+        if self.is_iqt:
+            middle_time_diff = (self.observation_end_time - self.observation_start_time) / 2
+            utc_date = self.observation_start_time + middle_time_diff
+            sun_earth_distance = sun_earth_distance_correction(utc_date)
+            logger.info(f"The value sun_earth_distance is set to {sun_earth_distance} AU.")
+        else:
+            sun_earth_distance = np.nanmean(
+                self._get_aux_data_lut_vector("earth_sun_distance")) / 149597870.7  # [AU]
+        return sun_earth_distance
+
 
 def _ensure_dataarray(arr):
     if not isinstance(arr, xr.DataArray):
