@@ -112,10 +112,9 @@ class BaseFileHandler:
         """
         combined_info = combine_metadata(*all_infos)
 
-        new_dict = self._combine(all_infos, min, "start_time", "start_orbit")
-        new_dict.update(self._combine(all_infos, max, "end_time", "end_orbit"))
+        new_dict = self._combine(all_infos, min, "start_orbit")
+        new_dict.update(self._combine(all_infos, max, "end_orbit"))
         new_dict.update(self._combine_orbital_parameters(all_infos))
-        new_dict.update(self._combine_time_parameters(all_infos))
 
         try:
             area = SwathDefinition(lons=np.ma.vstack([info["area"].lons for info in all_infos]),
@@ -145,27 +144,6 @@ class BaseFileHandler:
         orb_params_comb.update(self._combine(orb_params, np.mean, *keys))
         return {"orbital_parameters": orb_params_comb}
 
-    def _combine_time_parameters(self, all_infos):
-        time_params = [info.get("time_parameters", {}) for info in all_infos]
-        if not all(time_params):
-            return {}
-        # Collect all available keys
-        time_params_comb = {}
-        for d in time_params:
-            time_params_comb.update(d)
-
-        start_keys = (
-            "nominal_start_time",
-            "observation_start_time",
-        )
-        end_keys = (
-            "nominal_end_time",
-            "observation_end_time",
-        )
-        time_params_comb.update(self._combine(time_params, min, *start_keys))
-        time_params_comb.update(self._combine(time_params, max, *end_keys))
-        return {"time_parameters": time_params_comb}
-
     @property
     def start_time(self):
         """Get start time."""
