@@ -15,6 +15,7 @@
 #
 # You should have received a copy of the GNU General Public License along with
 # satpy.  If not, see <http://www.gnu.org/licenses/>.
+
 r"""Interface to SEVIRI L1B data from ICARE (Lille).
 
 Introduction
@@ -69,7 +70,8 @@ Output:
         ancillary_variables:  []
 
 """
-from datetime import datetime
+
+import datetime as dt
 
 import numpy as np
 
@@ -169,9 +171,9 @@ class SEVIRI_ICARE(HDF4FileHandler):
             attr = str(attr.astype(str))
         # In some versions milliseconds are present, sometimes not.
         try:
-            endacq = datetime.strptime(attr, "%Y-%m-%dT%H:%M:%SZ")
+            endacq = dt.datetime.strptime(attr, "%Y-%m-%dT%H:%M:%SZ")
         except ValueError:
-            endacq = datetime.strptime(attr, "%Y-%m-%dT%H:%M:%S.%fZ")
+            endacq = dt.datetime.strptime(attr, "%Y-%m-%dT%H:%M:%S.%fZ")
         return endacq
 
     @property
@@ -182,9 +184,9 @@ class SEVIRI_ICARE(HDF4FileHandler):
             attr = str(attr.astype(str))
         # In some versions milliseconds are present, sometimes not.
         try:
-            stacq = datetime.strptime(attr, "%Y-%m-%dT%H:%M:%SZ")
+            stacq = dt.datetime.strptime(attr, "%Y-%m-%dT%H:%M:%SZ")
         except ValueError:
-            stacq = datetime.strptime(attr, "%Y-%m-%dT%H:%M:%S.%fZ")
+            stacq = dt.datetime.strptime(attr, "%Y-%m-%dT%H:%M:%S.%fZ")
         return stacq
 
     @property
